@@ -38,19 +38,19 @@ The destructor.
 
 =head2 sa_family
 
-  method sa_family : byte ()
+  method sa_family : int ()
 
 Gets C<sa_family>. This is the overriden method of the L<sa_family|SPVM::Sys::Socket::Sockaddr/"sa_family"> method in the Sys::Socket::Sockaddr class.
 
 =head2 sin6_family
 
-  method sin6_family : byte ();
+  method sin6_family : int ();
 
 Gets C<sin6_family>.
 
 =head2 set_sin6_family
 
-  method set_sin6_family : void ($family : byte)
+  method set_sin6_family : void ($family : int)
 
 Sets C<sin6_family>.
 
@@ -92,13 +92,13 @@ Sets C<sin6_addr>. This is a L<Sys::Socket::In6_addr|SPVM::Sys::Socket::In6_addr
 
 =head2 sin6_port
 
-  method sin6_port : short ();
+  method sin6_port : int ();
 
 Gets C<sin6_port>.
 
 =head2 set_sin6_port
 
-  method set_sin6_port : void ($port : short);
+  method set_sin6_port : void ($port : int);
 
 Sets C<sin6_port>.
 
